@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2012, Phoronix Media
-	Copyright (C) 2008 - 2012, Michael Larabel
+	Copyright (C) 2008 - 2013, Phoronix Media
+	Copyright (C) 2008 - 2013, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -40,6 +40,11 @@ class pts_client
 	{
 		pts_define_directories(); // Define directories
 
+		if(function_exists('cli_set_process_title'))
+		{
+			cli_set_process_title('Phoronix Test Suite');
+		}
+
 		if(QUICK_START)
 		{
 			return true;
@@ -55,8 +60,8 @@ class pts_client
 		}
 
 		pts_config::init_files();
-		define('PTS_TEST_INSTALL_DEFAULT_PATH', pts_client::parse_home_directory(pts_config::read_user_config('PhoronixTestSuite/Options/Installation/EnvironmentDirectory', '~/.phoronix-test-suite/installed-tests/')));
-		define('PTS_SAVE_RESULTS_PATH', pts_client::parse_home_directory(pts_config::read_user_config('PhoronixTestSuite/Options/Testing/ResultsDirectory', '~/.phoronix-test-suite/test-results/')));
+		pts_define('PTS_TEST_INSTALL_DEFAULT_PATH', pts_client::parse_home_directory(pts_config::read_user_config('PhoronixTestSuite/Options/Installation/EnvironmentDirectory', '~/.phoronix-test-suite/installed-tests/')));
+		pts_define('PTS_SAVE_RESULTS_PATH', pts_client::parse_home_directory(pts_config::read_user_config('PhoronixTestSuite/Options/Testing/ResultsDirectory', '~/.phoronix-test-suite/test-results/')));
 		self::extended_init_process();
 
 		$openbenchmarking = pts_storage_object::read_from_file(PTS_CORE_STORAGE, 'openbenchmarking');
@@ -144,7 +149,7 @@ class pts_client
 		}
 
 		pts_module_manager::module_process('__startup');
-		define('PTS_STARTUP_TASK_PERFORMED', true);
+		pts_define('PTS_STARTUP_TASK_PERFORMED', true);
 		register_shutdown_function(array('pts_module_manager', 'module_process'), '__shutdown');
 	}
 	public static function open_basedir_check()
@@ -349,7 +354,7 @@ class pts_client
 						$cmd_output = shell_exec('cd ' . dirname($command_bin) . ' && ./' . $command_string . ' 2>&1');
 
 						// Try to filter out any serial numbers, etc.
-						$cmd_output = pts_strings::remove_lines_containing($cmd_output, array('Serial N', 'S/N', 'Serial #', 'serial:', 'serial='));
+						phodevi_vfs::cleanse_file($cmd_output, $command[0]);
 						$cmd_output = pts_strings::remove_line_timestamps($cmd_output);
 
 						file_put_contents($system_log_dir . $command[0], $cmd_output);
@@ -427,14 +432,14 @@ class pts_client
 		// Initialize The Phoronix Test Suite
 
 		// PTS Defines
-		define('PHP_BIN', pts_client::read_env('PHP_BIN'));
-		define('PTS_INIT_TIME', time());
+		pts_define('PHP_BIN', pts_client::read_env('PHP_BIN'));
+		pts_define('PTS_INIT_TIME', time());
 
 		if(!defined('PHP_VERSION_ID'))
 		{
 			// PHP_VERSION_ID is only available in PHP 5.2.6 and later
 			$php_version = explode('.', PHP_VERSION);
-			define('PHP_VERSION_ID', ($php_version[0] * 10000 + $php_version[1] * 100 + $php_version[2]));
+			pts_define('PHP_VERSION_ID', ($php_version[0] * 10000 + $php_version[1] * 100 + $php_version[2]));
 		}
 
 		$dir_init = array(PTS_USER_PATH);
@@ -590,13 +595,13 @@ class pts_client
 				$pso->add_object('global_system_id', $global_gsid['gsid']); // GSID
 				$pso->add_object('global_system_id_p', $global_gsid['gsid_p']); // GSID_P
 				$pso->add_object('global_system_id_e', $global_gsid['gsid_e']); // GSID_E
-				define('PTS_GSID', $global_gsid['gsid']);
-				define('PTS_GSID_E', $global_gsid['gsid_e']);
+				pts_define('PTS_GSID', $global_gsid['gsid']);
+				pts_define('PTS_GSID_E', $global_gsid['gsid_e']);
 			}
 		}
 		else if(pts_openbenchmarking::is_valid_gsid_e_format($global_gsid_e) == false || pts_openbenchmarking::is_valid_gsid_e_format($global_gsid_p) == false)
 		{
-			define('PTS_GSID', $global_gsid);
+			pts_define('PTS_GSID', $global_gsid);
 			$requested_gsid = false;
 			$global_gsid = pts_openbenchmarking_client::retrieve_gsid();
 
@@ -604,21 +609,21 @@ class pts_client
 			{
 				$pso->add_object('global_system_id_p', $global_gsid['gsid_p']); // GSID_P
 				$pso->add_object('global_system_id_e', $global_gsid['gsid_e']); // GSID_E
-				define('PTS_GSID_E', $global_gsid['gsid_e']);
+				pts_define('PTS_GSID_E', $global_gsid['gsid_e']);
 			}
 		}
 		else
 		{
-			define('PTS_GSID', $global_gsid);
-			define('PTS_GSID_E', $global_gsid_e);
+			pts_define('PTS_GSID', $global_gsid);
+			pts_define('PTS_GSID_E', $global_gsid_e);
 			$requested_gsid = false;
 		}
 
 		// Last Run Processing
 		$last_core_version = $pso->read_object('last_core_version');
-		define('FIRST_RUN_ON_PTS_UPGRADE', ($last_core_version != PTS_CORE_VERSION));
+		pts_define('FIRST_RUN_ON_PTS_UPGRADE', ($last_core_version != PTS_CORE_VERSION));
 
-		if(FIRST_RUN_ON_PTS_UPGRADE || ($pso->read_object('last_php_version') != phpversion()))
+		if(FIRST_RUN_ON_PTS_UPGRADE || ($pso->read_object('last_php_version') != PTS_PHP_VERSION))
 		{
 			// Report any missing/recommended extensions
 			self::program_requirement_checks();
@@ -634,7 +639,7 @@ class pts_client
 			pts_client::build_temp_cache();
 		}
 		$pso->add_object('last_core_version', PTS_CORE_VERSION); // PTS version last run
-		$pso->add_object('last_php_version', phpversion()); // PHP version last run
+		$pso->add_object('last_php_version', PTS_PHP_VERSION); // PHP version last run
 
 		//$last_pts_version = $pso->read_object('last_pts_version');
 		// do something here with $last_pts_version if you want that information
@@ -642,7 +647,7 @@ class pts_client
 
 		// Last Run Processing
 		$last_run = $pso->read_object('last_run_time');
-		define('IS_FIRST_RUN_TODAY', (substr($last_run, 0, 10) != date('Y-m-d')));
+		pts_define('IS_FIRST_RUN_TODAY', (substr($last_run, 0, 10) != date('Y-m-d')));
 		$pso->add_object('last_run_time', date('Y-m-d H:i:s')); // Time PTS was last run
 
 
@@ -837,7 +842,7 @@ class pts_client
 	public static function exit_client($string = null, $exit_status = 0)
 	{
 		// Exit the Phoronix Test Suite client
-		define('PTS_EXIT', 1);
+		pts_define('PTS_EXIT', 1);
 
 		if($string != null)
 		{
@@ -1504,7 +1509,7 @@ class pts_client
 
 		return $cache[$executable];
 	}
-	public static function display_web_page($URL, $alt_text = null, $default_open = false, $auto_open = false)
+	public static function display_web_page($URL, $alt_text = null, $default_open = true, $auto_open = false)
 	{
 		if(((pts_c::$test_flags & pts_c::auto_mode) && $auto_open == false && $default_open == false) || (pts_client::read_env('DISPLAY') == false && phodevi::is_windows() == false && phodevi::is_macosx() == false))
 		{
