@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2011, Phoronix Media
-	Copyright (C) 2010 - 2011, Michael Larabel
+	Copyright (C) 2010 - 2013, Phoronix Media
+	Copyright (C) 2010 - 2013, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -62,6 +62,13 @@ class pts_external_dependencies
 			}
 		}
 
+		if(!empty($required_test_dependencies))
+		{
+			// The 'common-dependencies' package is any general non-explicitly-required but nice-to-have packages like mesa-utils for providing glxinfo about the system
+			// So if we're going to be installing external dependencies anyways, might as well try to see the common-dependencies are satisfied
+			$required_test_dependencies['common-dependencies'] = array();
+		}
+
 		// Does the user wish to skip any particular dependencies?
 		if(pts_client::read_env('SKIP_EXTERNAL_DEPENDENCIES'))
 		{
@@ -103,7 +110,11 @@ class pts_external_dependencies
 			foreach(array_keys($required_test_dependencies) as $dependency)
 			{
 				$dependency_data = $exdep_generic_parser->get_package_data($dependency);
-				array_push($to_report, $dependency_data['title'] . PHP_EOL . 'Possible Package Names: ' . $dependency_data['possible_packages']);
+
+				if($dependency_data['possible_packages'] != null)
+				{
+					array_push($to_report, $dependency_data['title'] . PHP_EOL . 'Possible Package Names: ' . $dependency_data['possible_packages']);
+				}
 			}
 
 			if(count($to_report) > 0)
@@ -221,18 +232,29 @@ class pts_external_dependencies
 	}
 	private static function check_dependencies_missing_from_system(&$required_test_dependencies, &$generic_names_of_packages_needed = false)
 	{
-		$external_dependencies_parser = new pts_exdep_platform_parser(self::vendor_identifier('package-list'));
+		$generic_dependencies_parser = new pts_exdep_generic_parser();
+		$vendor_dependencies_parser = new pts_exdep_platform_parser(self::vendor_identifier('package-list'));
 		$kernel_architecture = phodevi::read_property('system', 'kernel-architecture');
 		$needed_os_packages = array();
 
-		foreach($external_dependencies_parser->get_available_packages() as $package)
+		foreach($required_test_dependencies as $package => $dependents)
 		{
-			if(isset($required_test_dependencies[$package]))
+			if($vendor_dependencies_parser->is_package($package))
 			{
-				$package_data = $external_dependencies_parser->get_package_data($package);
-				$add_dependency = empty($package_data['file_check']) || self::file_missing_check($package_data['file_check']);
+				$package_data = $vendor_dependencies_parser->get_package_data($package);
 				$arch_compliant = empty($package_data['arch_specific']) || in_array($kernel_architecture, $package_data['arch_specific']);
 
+				if(!empty($package_data['file_check']))
+				{
+					$add_dependency = self::file_missing_check($package_data['file_check']);
+				}
+				else if($generic_dependencies_parser->is_package($package))
+				{
+					// If the OS/platform-specific package didn't supply a file check list, obtain it from the generic listing
+					$generic_package_data = $generic_dependencies_parser->get_package_data($package);
+					$add_dependency = empty($generic_package_data['file_check']) || self::file_missing_check($generic_package_data['file_check']);
+				}
+
 				if($add_dependency && $arch_compliant && $package_data['os_package'] != null)
 				{
 					if(!in_array($package_data['os_package'], $needed_os_packages))
@@ -244,13 +266,15 @@ class pts_external_dependencies
 						array_push($generic_names_of_packages_needed, $package);
 					}
 				}
+				else
+				{
+					unset($required_test_dependencies[$package]);
+				}
 			}
 		}
 
 		if(count($required_test_dependencies) > 0)
 		{
-			$generic_dependencies_parser = new pts_exdep_generic_parser();
-
 			foreach($required_test_dependencies as $i => $dependency)
 			{
 				$package_data = $generic_dependencies_parser->get_package_data($i);
@@ -288,6 +312,65 @@ class pts_external_dependencies
 				{
 					$file_is_there = true;
 				}
+				else if(isset($file[$i][2]) && $file[$i][0] != '/')
+				{
+					// See if it's some relative command/path
+
+					if(substr($file[$i], -2) == '.h' || substr($file[$i], -4) == '.hpp')
+					{
+						// May just be a relative header file to look for...
+						$possible_paths = array('/usr/local/include', '/usr/target/include/', '/usr/include/');
+						foreach($possible_paths as $path)
+						{
+							if(is_file($path . $file[$i]) || is_link($path . $file[$i]))
+							{
+								$file_is_there = true;
+							}
+						}
+					}
+					else if(strpos($file[$i], '.so') !== false || substr($file[$i], -2) == '.a')
+					{
+						// May just be a relative shared library to look for...
+						$possible_paths = array('/usr/local/lib/', '/usr/lib/', '/usr/lib/x86_64-linux-gnu/', '/usr/lib/i386-linux-gnu/', '/usr/lib/arm-linux-gnueabihf/');
+
+						if(getenv('LD_LIBRARY_PATH'))
+						{
+							foreach(explode(':', getenv('LD_LIBRARY_PATH')) as $path)
+							{
+								array_push($possible_paths, $path . '/');
+							}
+						}
+
+						foreach($possible_paths as $path)
+						{
+							if(is_file($path . $file[$i]) || is_link($path . $file[$i]))
+							{
+								$file_is_there = true;
+							}
+						}
+					}
+					else if(strpos($file[$i], '/') === false)
+					{
+						// May just be a command to look for...
+						$possible_paths = array('/usr/local/bin/', '/usr/bin/');
+
+						if(getenv('PATH'))
+						{
+							foreach(explode(':', getenv('PATH')) as $path)
+							{
+								array_push($possible_paths, $path . '/');
+							}
+						}
+
+						foreach($possible_paths as $path)
+						{
+							if(is_file($path . $file[$i]) || is_link($path . $file[$i]))
+							{
+								$file_is_there = true;
+							}
+						}
+					}
+				}
 			}
 			$file_missing = $file_missing || !$file_is_there;
 		}
@@ -331,19 +414,39 @@ class pts_external_dependencies
 			case 'installer':
 				$file_check_success = is_file(PTS_EXDEP_PATH . 'scripts/install-' . $os_vendor . '-packages.sh');
 				break;
-			default:
-				return false;
 		}
 
 		if($file_check_success == false)
 		{
+			// Check the aliases to figure out the upstream distribution
+			$os_vendor = false;
 			$exdep_generic_parser = new pts_exdep_generic_parser();
-			$os_vendor = $exdep_generic_parser->find_vendor_alias($os_vendor);
-
-			if($os_vendor == false && is_file('/etc/debian_version'))
+			foreach($exdep_generic_parser->get_vendors_list() as $this_vendor)
 			{
-				// A simple last fall-back
-				$os_vendor = 'ubuntu';
+				$exdep_platform_parser = new pts_exdep_platform_parser($this_vendor);
+				$aliases = $exdep_platform_parser->get_aliases();
+
+				if(in_array($os_vendor, $aliases))
+				{
+					$os_vendor = $this_vendor;
+					break;
+				}
+			}
+
+			if($os_vendor == false)
+			{
+				// Attempt to match the current operating system by seeing what package manager matches
+				foreach($exdep_generic_parser->get_vendors_list() as $this_vendor)
+				{
+					$exdep_platform_parser = new pts_exdep_platform_parser($this_vendor);
+					$package_manager = $exdep_platform_parser->get_package_manager();
+
+					if($package_manager != null && pts_client::executable_in_path($package_manager))
+					{
+						$os_vendor = $this_vendor;
+						break;
+					}
+				}
 			}
 		}
 
