@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2012, Phoronix Media
-	Copyright (C) 2010 - 2012, Michael Larabel
+	Copyright (C) 2010 - 2013, Phoronix Media
+	Copyright (C) 2010 - 2013, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -242,7 +242,7 @@ class pts_openbenchmarking_client
 			{
 				if(!defined('HAS_REFRESHED_OBO_LIST'))
 				{
-					define('HAS_REFRESHED_OBO_LIST', true);
+					pts_define('HAS_REFRESHED_OBO_LIST', true);
 				}
 				else
 				{
@@ -599,7 +599,7 @@ class pts_openbenchmarking_client
 
 		return false;
 	}
-	public static function available_tests()
+	public static function available_tests($download_tests = true)
 	{
 		$available_tests = array();
 
@@ -611,7 +611,7 @@ class pts_openbenchmarking_client
 			{
 				foreach(array_keys($repo_index['tests']) as $identifier)
 				{
-					if(pts_network::network_support_available())
+					if($download_tests && pts_network::network_support_available())
 					{
 						$version = array_shift($repo_index['tests'][$identifier]['versions']);
 						if(self::download_test_profile($repo . '/' . $identifier . '-' . $version) == false)
@@ -627,7 +627,7 @@ class pts_openbenchmarking_client
 
 		return $available_tests;
 	}
-	public static function available_suites()
+	public static function available_suites($download_suites = true)
 	{
 		$available_suites = array();
 
@@ -639,7 +639,7 @@ class pts_openbenchmarking_client
 			{
 				foreach(array_keys($repo_index['suites']) as $identifier)
 				{
-					if(pts_network::network_support_available())
+					if($download_suites && pts_network::network_support_available())
 					{
 						$version = array_shift($repo_index['suites'][$identifier]['versions']);
 						if(self::download_test_suite($repo . '/' . $identifier . '-' . $version) == false)
@@ -672,6 +672,11 @@ class pts_openbenchmarking_client
 				$upload_data = array('test_identifier' => $test_result->test_profile->get_identifier(), 'test_version' => $test_result->test_profile->get_test_profile_version(), 'elapsed_time' => $time_elapsed);
 				pts_network::http_upload_via_post(pts_openbenchmarking::openbenchmarking_host() . 'extern/statistics/report-test-completion.php', $upload_data);
 				break;
+			case 'test_install_failure':
+				list($test_install, $error) = $data;
+				$upload_data = array('test_identifier' => $test_install->test_profile->get_identifier(), 'error' => $error, 'os' => phodevi::read_property('system', 'vendor-identifier'));
+				pts_network::http_upload_via_post(pts_openbenchmarking::openbenchmarking_host() . 'extern/statistics/report-test-install-failure.php', $upload_data);
+				break;
 		}
 	}
 	public static function upload_hwsw_data($to_report)
