@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2012, Phoronix Media
-	Copyright (C) 2008 - 2012, Michael Larabel
+	Copyright (C) 2008 - 2013, Phoronix Media
+	Copyright (C) 2008 - 2013, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -107,6 +107,7 @@ class pts_test_execution
 		{
 			pts_client::$display->test_run_instance_header($test_run_request);
 			$test_log_file = $test_directory . basename($test_identifier) . '-' . $runtime_identifier . '-' . ($i + 1) . '.log';
+			$is_expected_last_run = ($i == ($times_to_run - 1));
 
 			$test_extra_runtime_variables = array_merge($extra_runtime_variables, array(
 			'LOG_FILE' => $test_log_file
@@ -177,9 +178,19 @@ class pts_test_execution
 				$exit_status = pts_file_io::file_get_contents($test_directory . 'test-exit-status');
 				unlink($test_directory . 'test-exit-status');
 
-				if($exit_status != 0 && phodevi::is_bsd() == false)
+				if($exit_status != 0)
 				{
 					pts_client::$display->test_run_instance_error('The test exited with a non-zero exit status.');
+					if($is_expected_last_run && is_file($test_log_file))
+					{
+						$scan_log = pts_file_io::file_get_contents($test_log_file);
+						$test_run_error = pts_tests::scan_for_error($scan_log, $test_run_request->test_profile->get_test_executable_dir());
+
+						if($test_run_error)
+						{
+							pts_client::$display->test_run_instance_error('E: ' . $test_run_error);
+						}
+					}
 					$exit_status_pass = false;
 				}
 			}
@@ -199,10 +210,20 @@ class pts_test_execution
 
 				if(!empty($test_result))
 				{
-					if($test_run_time <= 10 && intval($test_result) == $test_result && $test_run_request->test_profile->get_estimated_run_time() > 60)
+					if($test_run_time < 3 && intval($test_result) == $test_result && $test_run_request->test_profile->get_estimated_run_time() > 60)
 					{
-						// If the test ended in less than 10 seconds, outputted some int, and normally the test takes much longer, then it's likely some invalid run
+						// If the test ended in less than 3 seconds, outputted some int, and normally the test takes much longer, then it's likely some invalid run
 						pts_client::$display->test_run_instance_error('The test run ended prematurely.');
+						if($is_expected_last_run && is_file($test_log_file))
+						{
+							$scan_log = pts_file_io::file_get_contents($test_log_file);
+							$test_run_error = pts_tests::scan_for_error($scan_log, $test_run_request->test_profile->get_test_executable_dir());
+
+							if($test_run_error)
+							{
+								pts_client::$display->test_run_instance_error('E: ' . $test_run_error);
+							}
+						}
 					}
 					else
 					{
@@ -212,6 +233,16 @@ class pts_test_execution
 				else if($test_run_request->test_profile->get_display_format() != 'NO_RESULT')
 				{
 					pts_client::$display->test_run_instance_error('The test run did not produce a result.');
+					if($is_expected_last_run && is_file($test_log_file))
+					{
+						$scan_log = pts_file_io::file_get_contents($test_log_file);
+						$test_run_error = pts_tests::scan_for_error($scan_log, $test_run_request->test_profile->get_test_executable_dir());
+
+						if($test_run_error)
+						{
+							pts_client::$display->test_run_instance_error('E: ' . $test_run_error);
+						}
+					}
 				}
 
 				if($allow_cache_share && !is_file($cache_share_pt2so))
@@ -222,7 +253,7 @@ class pts_test_execution
 				}
 			}
 
-			if($i == ($times_to_run - 1) && $test_run_request->test_result_buffer->get_count() > floor(($i - 2) / 2))
+			if($is_expected_last_run && $test_run_request->test_result_buffer->get_count() > floor(($i - 2) / 2))
 			{
 				// The later check above ensures if the test is failing often the run count won't uselessly be increasing
 				// Should we increase the run count?
@@ -402,7 +433,9 @@ class pts_test_execution
 			pts_test_notes_manager::add_note($note);
 		}
 
+		// As of PTS 4.4, this is removed and superceded effectively by reporting the notes to table
 		// Any special information (such as forced AA/AF levels for graphics) to add to the description string of the result?
+		/*
 		if(($special_string = phodevi::read_special_settings_string($test_type)) != null)
 		{
 			if(strpos($arguments_description, $special_string) === false)
@@ -415,6 +448,7 @@ class pts_test_execution
 				$arguments_description .= $special_string;
 			}
 		}
+		*/
 
 		// Result Calculation
 		$test_run_request->set_used_arguments_description($arguments_description);
