@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2012, Phoronix Media
-	Copyright (C) 2010 - 2012, Michael Larabel
+	Copyright (C) 2010 - 2013, Phoronix Media
+	Copyright (C) 2010 - 2013, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -34,7 +34,8 @@ class pts_test_installer
 		pts_client::set_test_flags($test_flags);
 
 		// Get the test profiles
-		$test_profiles = pts_types::identifiers_to_test_profile_objects($items_to_install, true, true);
+		$unknown_tests = array();
+		$test_profiles = pts_types::identifiers_to_test_profile_objects($items_to_install, true, true, $unknown_tests);
 
 		// Any external dependencies?
 		pts_external_dependencies::install_dependencies($test_profiles);
@@ -46,12 +47,12 @@ class pts_test_installer
 			return false;
 		}
 
-		pts_test_installer::start_install($test_profiles);
+		pts_test_installer::start_install($test_profiles, $unknown_tests);
 		pts_client::release_lock($lock_path);
 
 		return $test_profiles;
 	}
-	public static function start_install(&$test_profiles)
+	public static function start_install(&$test_profiles, &$unknown_tests = null)
 	{
 		if(count($test_profiles) == 0)
 		{
@@ -86,6 +87,14 @@ class pts_test_installer
 			}
 		}
 
+		if($unknown_tests)
+		{
+			foreach($unknown_tests as $unkown)
+			{
+				pts_client::$display->generic_sub_heading('Unknown: ' . $unkown);
+			}
+		}
+
 		if($test_install_manager->tests_to_install_count() == 0)
 		{
 			return true;
@@ -120,17 +129,25 @@ class pts_test_installer
 			}
 			else
 			{
-				array_push($failed_installs, $test_install_request->test_profile);
+				array_push($failed_installs, $test_install_request);
 			}
 		}
 		pts_module_manager::module_process('__post_install_process', $test_install_manager);
 		pts_download_speed_manager::save_data();
 
-		if(count($failed_installs) > 0)
+		if(count($failed_installs) > 1)
 		{
 			echo PHP_EOL . 'The following tests failed to install:' . PHP_EOL . PHP_EOL;
-			echo pts_user_io::display_text_list($failed_installs, "\t- ");
-			echo PHP_EOL;
+			foreach($failed_installs as &$install_request)
+			{
+				echo '  - ' . $install_request->test_profile . PHP_EOL;
+
+				// If many tests are being installed, show the error messages reported in order to reduce scrolling...
+				if($install_request->install_error && isset($failed_installs[5]))
+				{
+					echo '    [' . $install_request->install_error . ']' . PHP_EOL;
+				}
+			}
 		}
 	}
 	public static function only_download_test_files(&$test_profiles, $to_dir = null)
@@ -407,7 +424,7 @@ class pts_test_installer
 		if($test_install_request === false || in_array('fortran-compiler', $test_install_request->test_profile->get_dependencies()))
 		{
 			// Handle Fortran for this external dependency
-			$compilers['F9X'] = array(pts_strings::first_in_string(pts_client::read_env('F9X'), ' '), pts_strings::first_in_string(pts_client::read_env('F95'), ' '), 'gfortran', 'f95', 'fortran');
+			$compilers['F9X'] = array(pts_strings::first_in_string(pts_client::read_env('F9X'), ' '), pts_strings::first_in_string(pts_client::read_env('F95'), ' '), 'gfortran', 'f90', 'f95', 'fortran');
 		}
 
 		if(empty($compilers))
@@ -529,6 +546,7 @@ class pts_test_installer
 
 			// Clean-up / reduce the compiler options that are important
 			$compiler_options = null;
+			$compiler_backup_line = null;
 			foreach($compiler_lines as $l => $compiler_line)
 			{
 				$compiler_line .= ' '; // allows for easier/simplified detection in a few checks below
@@ -540,12 +558,20 @@ class pts_test_installer
 				}
 
 				$o = substr($compiler_line, ($o + 3), (strpos($compiler_line, ' ', ($o + 3)) - $o - 3));
+				$o_l = strlen($o);
 				// $o now has whatever is set for the -o output
 
-				if(!isset($o[4]) || substr($o, -2) == '.o' || substr(basename($o), 0, 3) == 'lib' || substr($o, -4) == 'test')
+				if(($o_l > 2 && substr(basename($o), 0, 3) == 'lib') || ($o_l > 3 && substr($o, -4) == 'test'))
+				{
+					// If it's a lib, probably not what is the actual target
+					unset($compiler_lines[$l]);
+					continue;
+				}
+				else if(($o_l > 2 && substr($o, -2) == '.o'))
 				{
 					// If it's outputting to a .o should not be the proper compile command we want
-					// Or if it's a lib, probably not what is the actual target either
+					// but back it up in case... keep overwriting temp variable to get the last one
+					$compiler_backup_line = $compiler_line;
 					unset($compiler_lines[$l]);
 					continue;
 				}
@@ -554,6 +580,12 @@ class pts_test_installer
 			if(!empty($compiler_lines))
 			{
 				$compiler_line = array_pop($compiler_lines);
+
+				if(strpos($compiler_line, '-O') === false && strpos($compiler_line, '-f') === false && (strpos($compiler_backup_line, '-f') !== false || strpos($compiler_backup_line, '-O')))
+				{
+					$compiler_line .= ' ' . $compiler_backup_line;
+				}
+
 				$compiler_options = explode(' ', $compiler_line);
 
 				foreach($compiler_options as $i => $option)
@@ -666,14 +698,35 @@ class pts_test_installer
 					$install_exit_status = pts_file_io::file_get_contents($test_install_directory . 'install-exit-status');
 					unlink($test_install_directory . 'install-exit-status');
 
-					if($install_exit_status != 0 && phodevi::is_bsd() == false && phodevi::is_windows() == false)
+					if($install_exit_status != 0 && phodevi::is_windows() == false)
 					{
+						$install_error = null;
+
 						// TODO: perhaps better way to handle this than to remove pts-install.xml
 						pts_file_io::unlink($test_install_directory . 'pts-install.xml');
-						copy($test_install_directory . 'install.log', $test_install_directory . 'install-failed.log');
+
+						if(is_file($test_install_directory . 'install.log'))
+						{
+							$install_log = pts_file_io::file_get_contents($test_install_directory . 'install.log');
+							$install_error = pts_tests::scan_for_error($install_log, $test_install_directory);
+							copy($test_install_directory . 'install.log', $test_install_directory . 'install-failed.log');
+						}
+
 						pts_test_installer::setup_test_install_directory($test_install_request, true); // Remove installed files from the bunked installation
 						pts_client::$display->test_install_error('The installer exited with a non-zero exit status.');
-						pts_client::$display->test_install_error('Installation Log: ' . $test_install_directory . 'install-failed.log' . PHP_EOL);
+						if($install_error != null)
+						{
+							$test_install_request->install_error = pts_tests::pretty_error_string($install_error);
+							pts_client::$display->test_install_error('ERROR: ' . $test_install_request->install_error);
+						}
+						pts_client::$display->test_install_error('LOG: ' . str_replace(pts_client::user_home_directory(), '~/', $test_install_directory) . 'install-failed.log' . PHP_EOL);
+
+						if(pts_client::do_anonymous_usage_reporting())
+						{
+							// If anonymous usage reporting enabled, report test install failure to OpenBenchmarking.org
+							pts_openbenchmarking_client::upload_usage_data('test_install_failure', array($test_install_request, $install_error));
+						}
+
 						return false;
 					}
 				}
