@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2012, Phoronix Media
-	Copyright (C) 2009 - 2012, Michael Larabel
+	Copyright (C) 2009 - 2013, Phoronix Media
+	Copyright (C) 2009 - 2013, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -49,6 +49,7 @@ class pts_test_run_manager
 	private $dynamic_run_count_export_script;
 
 	private static $test_run_process_active = false;
+	private static $batch_mode_options = false;
 
 	public function __construct($test_flags = 0)
 	{
@@ -293,7 +294,7 @@ class pts_test_run_manager
 			//echo 'Saving Results To: ' . $proposed_name . PHP_EOL;
 		}
 
-		if((pts_c::$test_flags ^ pts_c::batch_mode) || pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptSaveName', 'FALSE'))
+		if((pts_c::$test_flags ^ pts_c::batch_mode) || self::$batch_mode_options['PromptSaveName'])
 		{
 			$is_reserved_word = false;
 			// Be of help to the user by showing recently saved test results
@@ -355,7 +356,7 @@ class pts_test_run_manager
 			$current_software = array();
 		}
 
-		if((pts_c::$test_flags ^ pts_c::batch_mode) || pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptForTestIdentifier', 'TRUE') && (pts_c::$test_flags ^ pts_c::auto_mode) && (pts_c::$test_flags ^ pts_c::is_recovering))
+		if((pts_c::$test_flags ^ pts_c::batch_mode) || self::$batch_mode_options['PromptForTestIdentifier'] && (pts_c::$test_flags ^ pts_c::auto_mode) && (pts_c::$test_flags ^ pts_c::is_recovering))
 		{
 			if(count($current_identifiers) > 0)
 			{
@@ -656,7 +657,7 @@ class pts_test_run_manager
 	public static function clean_save_name($input, $is_new_save = true)
 	{
 		$input = pts_client::swap_variables($input, array('pts_client', 'user_run_save_variables'));
-		$input = str_replace(array('--', '---'), '-', pts_strings::keep_in_string(str_replace(' ', '-', trim($input)), pts_strings::CHAR_LETTER | pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DASH));
+		$input = pts_strings::remove_redundant(pts_strings::keep_in_string(str_replace(' ', '-', trim($input)), pts_strings::CHAR_LETTER | pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DASH), '-');
 
 		if($is_new_save)
 		{
@@ -675,7 +676,12 @@ class pts_test_run_manager
 
 		if((pts_c::$test_flags & pts_c::batch_mode))
 		{
-			if(pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/Configured', 'FALSE') == false && (pts_c::$test_flags ^ pts_c::auto_mode))
+			if(self::$batch_mode_options === false)
+			{
+				self::set_batch_mode();
+			}
+
+			if(self::$batch_mode_options['Configured'] == false && (pts_c::$test_flags ^ pts_c::auto_mode))
 			{
 				pts_client::$display->generic_error('The batch mode must first be configured.' . PHP_EOL . 'To configure, run phoronix-test-suite batch-setup');
 				return false;
@@ -792,6 +798,18 @@ class pts_test_run_manager
 			{
 				$notes['graphics-2d-acceleration'] = $accel_2d;
 			}
+
+			$aa = phodevi::read_property('gpu', 'aa-level');
+			if($aa)
+			{
+				$notes['graphics-aa'] = $aa;
+			}
+
+			$af = phodevi::read_property('gpu', 'af-level');
+			if($af)
+			{
+				$notes['graphics-af'] = $af;
+			}
 		}
 
 		return $notes;
@@ -828,7 +846,7 @@ class pts_test_run_manager
 				}
 				else if((pts_c::$test_flags & pts_c::batch_mode))
 				{
-					$upload_results = pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/UploadResults', 'TRUE');
+					$upload_results = self::$batch_mode_options['UploadResults'];
 				}
 				else if((pts_c::$test_flags ^ pts_c::auto_mode))
 				{
@@ -858,6 +876,28 @@ class pts_test_run_manager
 			}
 		}
 	}
+	public static function set_batch_mode($custom_preset = false)
+	{
+		self::$batch_mode_options = array(
+			'UploadResults' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/UploadResults', 'TRUE'),
+			'SaveResults' => pts_config::read_user_config('PhoronixTestSuite/Options/BatchMode/SaveResults', 'TRUE'),
+			'PromptForTestDescription' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptForTestDescription', 'FALSE'),
+			'RunAllTestCombinations' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/RunAllTestCombinations', 'TRUE'),
+			'PromptSaveName' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptSaveName', 'FALSE'),
+			'PromptForTestIdentifier' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptForTestIdentifier', 'TRUE'),
+			'Configured' => pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/Configured', 'FALSE'),
+			);
+
+		if($custom_preset && is_array($custom_preset))
+		{
+			foreach($custom_preset as $key => $value)
+			{
+				self::$batch_mode_options[$key] = $value;
+			}
+
+			self::$batch_mode_options['Configured'] = true;
+		}
+	}
 	public static function cleanup_tests_to_run(&$to_run_objects)
 	{
 		$skip_tests = ($e = pts_client::read_env('SKIP_TESTS')) ? pts_strings::comma_explode($e) : false;
@@ -1108,7 +1148,7 @@ class pts_test_run_manager
 			}
 			else if((pts_c::$test_flags & pts_c::batch_mode))
 			{
-				$save_results = pts_config::read_user_config('PhoronixTestSuite/Options/BatchMode/SaveResults', 'TRUE');
+				$save_results = self::$batch_mode_options['SaveResults'];
 			}
 			else
 			{
@@ -1130,7 +1170,7 @@ class pts_test_run_manager
 				}
 
 				// Prompt Description
-				if((pts_c::$test_flags ^ pts_c::batch_mode) || pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/PromptForTestDescription', 'FALSE'))
+				if((pts_c::$test_flags ^ pts_c::batch_mode) || self::$batch_mode_options['PromptForTestDescription'])
 				{
 					if($this->run_description == null)
 					{
@@ -1243,7 +1283,7 @@ class pts_test_run_manager
 	{
 		$result_objects = array();
 
-		if((pts_c::$test_flags & pts_c::batch_mode) && pts_config::read_bool_config('PhoronixTestSuite/Options/BatchMode/RunAllTestCombinations', 'TRUE'))
+		if((pts_c::$test_flags & pts_c::batch_mode) && self::$batch_mode_options['RunAllTestCombinations'])
 		{
 			list($test_arguments, $test_arguments_description) = pts_test_run_options::batch_user_options($test_profile);
 		}
@@ -1428,6 +1468,7 @@ class pts_test_run_manager
 		$test_type = $test_profile->get_test_hardware_type();
 		$skip_tests = pts_client::read_env('SKIP_TESTS') ? pts_strings::comma_explode(pts_client::read_env('SKIP_TESTS')) : false;
 		$display_driver = phodevi::read_property('system', 'display-driver');
+		$gpu = phodevi::read_name('gpu');
 
 		if($test_profile->is_supported(false) == false)
 		{
@@ -1438,8 +1479,9 @@ class pts_test_run_manager
 			$report_errors && pts_client::$display->test_run_error('No display server was found, cannot run ' . $test_profile);
 			$valid_test_profile = false;
 		}
-		else if($test_type == 'Graphics' && in_array($display_driver, array('vesa', 'nv', 'cirrus')))
+		else if($test_type == 'Graphics' && in_array($display_driver, array('vesa', 'nv', 'cirrus')) && stripos($gpu, 'LLVM') === false)
 		{
+			// These display drivers end up being in known configurations without 3D hardware support so unless an LLVM-based string is reported as the GPU, don't advertise 3D tests
 			$report_errors && pts_client::$display->test_run_error('3D acceleration support not available, cannot run ' . $test_profile);
 			$valid_test_profile = false;
 		}
@@ -1459,6 +1501,12 @@ class pts_test_run_manager
 			$valid_test_profile = false;
 		}
 
+		if($valid_test_profile == false && pts_client::read_env('SKIP_ALL_TEST_SUPPORT_CHECKS'))
+		{
+			$valid_test_profile = true;
+			$report_errors && pts_client::$display->test_run_error('SKIP_ALL_TEST_SUPPORT_CHECKS is set for ' . $test_profile . '.');
+		}
+
 		return $valid_test_profile;
 	}
 	protected function validate_test_to_run(&$test_profile)
