@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2012, Phoronix Media
-	Copyright (C) 2008 - 2012, Michael Larabel
+	Copyright (C) 2008 - 2013, Phoronix Media
+	Copyright (C) 2008 - 2013, Michael Larabel
 	phodevi_gpu.php: The PTS Device Interface object for the graphics processor
 
 	This program is free software; you can redistribute it and/or modify
@@ -113,29 +113,6 @@ class phodevi_gpu extends phodevi_device_interface
 
 		return $property;
 	}
-	public static function special_settings_string()
-	{
-		$special_string = null;
-		$extra_gfx_settings = array();
-		$aa_level = phodevi::read_property('gpu', 'aa-level');
-		$af_level = phodevi::read_property('gpu', 'af-level');
-
-		if($aa_level)
-		{
-			array_push($extra_gfx_settings, 'AA: ' . $aa_level);
-		}
-		if($af_level)
-		{
-			array_push($extra_gfx_settings, 'AF: ' . $af_level);
-		}
-
-		if(count($extra_gfx_settings) > 0)
-		{
-			$special_string = implode(' - ', $extra_gfx_settings);
-		}
-
-		return $special_string;
-	}
 	public static function gpu_set_resolution($args)
 	{
 		if(count($args) != 2 || phodevi::is_windows() || phodevi::is_macosx() || !pts_client::executable_in_path('xrandr'))
@@ -252,6 +229,15 @@ class phodevi_gpu extends phodevi_device_interface
 				}
 			}
 		}
+		else if(phodevi::is_mesa_graphics())
+		{
+			$gallium_msaa = getenv('GALLIUM_MSAA');
+			if(is_numeric($gallium_msaa) && $gallium_msaa > 0)
+			{
+				// Simple test to try to figure out if the GALLIUM_MSAA anti-aliasing value was forced
+				$aa_level = $gallium_msaa . 'x MSAA';
+			}
+		}
 
 		return $aa_level;
 	}
@@ -690,6 +676,12 @@ class phodevi_gpu extends phodevi_device_interface
 				$info = substr($info, 0, $x);
 				$info = substr($info, strrpos($info, ' ') + 1);
 			}
+			else if(($x = strpos($info, 'VRAM: ')) !== false)
+			{
+				// Nouveau DRM around Linux ~3.6 reports e.g.: DRM] VRAM: 512 MiB
+				$info = substr($info, ($x + 6));
+				$info = substr($info, 0, strpos($info, ' '));
+			}
 
 			if(is_numeric($info))
 			{
@@ -864,7 +856,12 @@ class phodevi_gpu extends phodevi_device_interface
 					if($core_freq == 0 && isset(phodevi::$vfs->i915_cur_delayinfo))
 					{
 						$i915_cur_delayinfo = phodevi::$vfs->i915_cur_delayinfo;
-						$freq = strpos($i915_cur_delayinfo, 'Max non-overclocked (RP0) frequency: ');
+						$freq = strpos($i915_cur_delayinfo, 'Max overclocked frequency: ');
+
+						if($freq === false)
+						{
+							$freq = strpos($i915_cur_delayinfo, 'Max non-overclocked (RP0) frequency: ');
+						}
 
 						if($freq === false)
 						{
