@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2012, Phoronix Media
-	Copyright (C) 2008 - 2012, Michael Larabel
+	Copyright (C) 2008 - 2013, Phoronix Media
+	Copyright (C) 2008 - 2013, Michael Larabel
 	phodevi_system.php: The PTS Device Interface object for the system software
 
 	This program is free software; you can redistribute it and/or modify
@@ -304,14 +304,17 @@ class phodevi_system extends phodevi_device_interface
 							'0x5346414f' => 'OpenAFS',
 							'0x47504653' => 'GPFS',
 							'0x5941ff53' => 'YAFFS',
-							'0x65735546' => 'SSHFS',
 							'0xff534d42' => 'CIFS',
 							'0x24051905' => 'UBIFS',
 							'0x1021994' => 'TMPFS',
 							'0x73717368' => 'SquashFS',
 							'0xc97e8168' => 'LogFS',
-							'0x65735546' => 'SSHFS',
-							'0x5346544E' => 'NTFS'
+							'0x5346544E' => 'NTFS',
+							'0xf15f' => 'eCryptfs',
+							'0x61756673' => 'AuFS',
+							'0xbd00bd0' => 'Lustre',
+							'0xaad7aaea' => 'PanFS', // Panasas FS
+							'0xf2f52010' => 'F2FS'
 							);
 
 						foreach($known_magic_blocks as $hex => $name)
@@ -576,9 +579,13 @@ class phodevi_system extends phodevi_device_interface
 					$compiler_info = null;
 				}
 			}
+			else
+			{
+				$compiler_info = substr($compiler_info, 0, strpos($compiler_info, PHP_EOL));
+			}
 
 			// Clang
-			if(empty($compiler_info))
+			if(empty($compiler_info) && stripos($compiler_info, 'not found'))
 			{
 				// At least with Clang ~3.0 the -dumpversion is reporting '4.2.1' ratherthan the useful information...
 				// This is likely just for GCC command compatibility, so only use this as a fallback
@@ -1010,7 +1017,7 @@ class phodevi_system extends phodevi_device_interface
 			$desktop_environment = 'Xfce';
 			$xfce_output = trim(shell_exec('xfce4-session-settings --version 2>&1'));
 
-			if(($open = strpos($xfce_output, '(')) > 0)
+			if(($open = strpos($xfce_output, '(Xfce')) > 0)
 			{
 				$xfce_output = substr($xfce_output, strpos($xfce_output, ' ', $open) + 1);
 				$desktop_version = substr($xfce_output, 0, strpos($xfce_output, ')'));
@@ -1038,6 +1045,21 @@ class phodevi_system extends phodevi_device_interface
 			$desktop_environment = 'Cinnamon';
 			$desktop_version = pts_strings::last_in_string(trim(shell_exec('cinnamon --version 2> /dev/null')));
 		}
+		else if(pts_client::is_process_running('enlightenment'))
+		{
+			$desktop_environment = 'Enlightenment';
+			$desktop_version = null; // No known -v / --version command on any Enlightenment component
+		}
+		else if(pts_client::is_process_running('consort-panel'))
+		{
+			$desktop_environment = 'Consort';
+			$desktop_version = null; // TODO: Haven't tested Consort Desktop yet
+		}
+		else if(pts_client::is_process_running('razor-desktop'))
+		{
+			$desktop_environment = 'Razor-qt';
+			$desktop_version = null; // TODO: Figure out how to determine razor version
+		}
 
 		if(!empty($desktop_environment))
 		{
@@ -1053,6 +1075,8 @@ class phodevi_system extends phodevi_device_interface
 	}
 	public static function sw_display_server()
 	{
+		$info = null;
+
 		if(phodevi::is_windows())
 		{
 			// TODO: determine what to do for Windows support
@@ -1060,32 +1084,34 @@ class phodevi_system extends phodevi_device_interface
 		}
 		else
 		{
-			if(!(($x_bin = pts_client::executable_in_path('Xorg')) || ($x_bin = pts_client::executable_in_path('X'))))
+			if(($x_bin = pts_client::executable_in_path('Xorg')) || ($x_bin = pts_client::executable_in_path('X')))
 			{
-				return false;
-			}
+				// Find graphics subsystem version
+				$info = shell_exec($x_bin . ' ' . (phodevi::is_solaris() ? ':0' : '') . ' -version 2>&1');
+				$pos = (($p = strrpos($info, 'Release Date')) !== false ? $p : strrpos($info, 'Build Date'));
+				$info = trim(substr($info, 0, $pos));
 
-			// Find graphics subsystem version
-			$info = shell_exec($x_bin . ' ' . (phodevi::is_solaris() ? ':0' : '') . ' -version 2>&1');
-			$pos = (($p = strrpos($info, 'Release Date')) !== false ? $p : strrpos($info, 'Build Date'));
-			$info = trim(substr($info, 0, $pos));
+				if($pos === false || getenv('DISPLAY') == false)
+				{
+					$info = null;
+				}
+				else if(($pos = strrpos($info, '(')) === false)
+				{
+					$info = trim(substr($info, strrpos($info, ' ')));
+				}
+				else
+				{
+					$info = trim(substr($info, strrpos($info, 'Server') + 6));
+				}
 
-			if($pos === false || getenv('DISPLAY') == false)
-			{
-				$info = null;
+				if($info != null)
+				{
+					$info = 'X Server ' . $info;
+				}
 			}
-			else if(($pos = strrpos($info, '(')) === false)
+			else if(pts_client::is_process_running('surfaceflinger'))
 			{
-				$info = trim(substr($info, strrpos($info, ' ')));
-			}
-			else
-			{
-				$info = trim(substr($info, strrpos($info, 'Server') + 6));
-			}
-
-			if($info != null)
-			{
-				$info = 'X Server ' . $info;
+				$info = 'SurfaceFlinger';
 			}
 		}
 
@@ -1167,6 +1193,7 @@ class phodevi_system extends phodevi_device_interface
 						}
 						break;
 					case 'nvidia':
+					case 'NVIDIA':
 						// NVIDIA's binary driver usually ends up reporting 1.0.0
 						if(($nvs_value = phodevi_parser::read_nvidia_extension('NvidiaDriverVersion')))
 						{
@@ -1201,7 +1228,7 @@ class phodevi_system extends phodevi_device_interface
 				$display_driver = null;
 
 				// See if the VESA or fbdev driver is in use
-				foreach(array('vesa', 'fbdev', 'modesetting') as $drv)
+				foreach(array('modesetting', 'fbdev', 'vesa') as $drv)
 				{
 					$drv_version = phodevi_parser::read_xorg_module_version($drv . '_drv');
 
@@ -1218,7 +1245,8 @@ class phodevi_system extends phodevi_device_interface
 			{
 				$display_driver .= ' ' . $driver_version;
 
-				if(phodevi::is_ati_graphics() && strpos($display_driver, 'fglrx') !== false)
+				// XXX: The below check is disabled since the Catalyst Version no longer seems reliably reported (circa Catalyst 13.x)
+				if(false && phodevi::is_ati_graphics() && strpos($display_driver, 'fglrx') !== false)
 				{
 					$catalyst_version = phodevi_linux_parser::read_amd_pcsdb('AMDPCSROOT/SYSTEM/LDC,Catalyst_Version');
 
