@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2012, Phoronix Media
-	Copyright (C) 2008 - 2012, Michael Larabel
+	Copyright (C) 2008 - 2013, Phoronix Media
+	Copyright (C) 2008 - 2013, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -63,8 +63,9 @@ class pts_network
 			return false;
 		}
 
-		if(function_exists('curl_init'))
+		if(function_exists('curl_init') && stripos(PTS_PHP_VERSION, 'hiphop') === false)
 		{
+			// XXX: Facebook HipHop HHVM currently seems to have problems with PHP CURL
 			$return_state = pts_network::curl_download($download, $to);
 		}
 		else
@@ -119,9 +120,9 @@ class pts_network
 			curl_setopt($cr, CURLOPT_CAINFO, PTS_CORE_STATIC_PATH . 'certificates/phoromatic-com.pem');
 		}
 
-		if(PHP_VERSION_ID >= 50300)
+		if(PHP_VERSION_ID >= 50300 && defined('CURLOPT_PROGRESSFUNCTION'))
 		{
-			// CURLOPT_PROGRESSFUNCTION only seems to work with PHP 5.3+
+			// CURLOPT_PROGRESSFUNCTION only seems to work with PHP 5.3+, but is not working with HipHop HHVM ~2.0.1
 			curl_setopt($cr, CURLOPT_NOPROGRESS, false);
 			curl_setopt($cr, CURLOPT_PROGRESSFUNCTION, array('pts_network', 'curl_status_callback'));
 		}
@@ -245,7 +246,7 @@ class pts_network
 			self::$network_proxy['port'] = $env_proxy[1];
 		}
 
-		define('NETWORK_TIMEOUT', pts_config::read_user_config('PhoronixTestSuite/Options/Networking/Timeout', 20));
+		pts_define('NETWORK_TIMEOUT', pts_config::read_user_config('PhoronixTestSuite/Options/Networking/Timeout', 20));
 
 		if(ini_get('allow_url_fopen') == 'Off')
 		{
